import { Argument, ArgumentOptions } from './Argument';
import type { CommandContext } from './contexts/CommandContext';
import { AutoDeferType, GClient } from '../GClient';
import { PermissionResolvable, LocaleString } from 'discord.js';
export declare enum CommandType {
    /**
     * ![](https://garlic-team.js.org/guide/message.png)
     */
    'MESSAGE' = 0,
    /**
     * ![](https://garlic-team.js.org/guide/slash.png)
     */
    'SLASH' = 1,
    /**
     * ![](https://garlic-team.js.org/guide/context_user.png)
     */
    'CONTEXT_USER' = 2,
    /**
     * ![](https://garlic-team.js.org/guide/context_message.png)
     */
    'CONTEXT_MESSAGE' = 3
}
export declare type CommandInhibitor = ((ctx: CommandContext) => boolean | any) | {
    run: CommandInhibitor;
};
export declare type CommandInhibitors = Array<CommandInhibitor>;
export interface CommandOptions {
    name: string;
    nameLocalizations?: Record<LocaleString, string>;
    description: string;
    descriptionLocalizations?: Record<LocaleString, string>;
    type: Array<CommandType | keyof typeof CommandType>;
    defaultMemberPermissions?: PermissionResolvable;
    dmPermission?: boolean;
    arguments?: Array<Argument | ArgumentOptions>;
    inhibitors?: CommandInhibitors;
    guildId?: string;
    cooldown?: string;
    autoDefer?: AutoDeferType | keyof typeof AutoDeferType;
    fileName?: string;
    run?: (ctx: CommandContext) => any;
    onError?: (ctx: CommandContext, error: any) => any;
}
export declare class Command {
    client: GClient;
    name: string;
    nameLocalizations?: Record<LocaleString, string>;
    description: string;
    descriptionLocalizations?: Record<LocaleString, string>;
    type: Array<CommandType | keyof typeof CommandType>;
    defaultMemberPermissions?: PermissionResolvable;
    dmPermission?: boolean;
    arguments?: Array<Argument>;
    inhibitors: CommandInhibitors;
    options: Partial<CommandOptions>;
    guildId?: string;
    private static defaults?;
    cooldown?: string;
    fileName?: string;
    run: (ctx: CommandContext) => any;
    onError?: (ctx: CommandContext, error: any) => any;
    owner?: string;
    reloading: boolean;
    autoDefer?: AutoDeferType | keyof typeof AutoDeferType;
    constructor(options: CommandOptions);
    initialize(client: GClient): void;
    unregister(): Command;
    inhibit(ctx: CommandContext): Promise<boolean>;
    reload(): Promise<Command>;
    toJSON(): Array<Record<string, any>>;
    static setDefaults(defaults: Partial<CommandOptions>): void;
}
//# sourceMappingURL=Command.d.ts.map